#
# spec file for package adobe-sourcesanspro-fonts
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Dominique Leuenberger, Amsterdam, Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define it_version 1.095
%define ro_version 2.045
%define _name SourceSansPro
Name:           adobe-sourcesanspro-fonts
Version:        %{ro_version}
Release:        2.10
Summary:        A set of OpenType fonts designed for user interfaces
License:        OFL-1.1
Group:          System/X11/Fonts
URL:            https://github.com/adobe/source-sans-pro/
Source:         https://github.com/adobe-fonts/source-sans-pro/releases/download/%{version}R-ro%2F%{it_version}R-it/source-sans-pro-%{ro_version}R-ro-%{it_version}R-it.zip
BuildRequires:  fontpackages-devel
BuildRequires:  unzip
BuildArch:      noarch
%reconfigure_fonts_prereq

%description
Source Sans is a set of OpenType fonts that have been designed to work well in user interface (UI) environments, as well as in text setting for screen and print.

%prep
%setup -q -n source-sans-pro-%{ro_version}R-ro-%{it_version}R-it
# Fix line endings
sed -i 's/\r$//g' LICENSE.txt
# fix spurious-executable-perm
chmod -x README.md

%build

%install
install -d %{buildroot}%{_ttfontsdir}
# by default install command uses 755 umask
install -m 644 OTF/*.otf %{buildroot}%{_ttfontsdir}

%reconfigure_fonts_scriptlets

%files
%license LICENSE.txt
%doc *.md
%dir %{_ttfontsdir}
%{_ttfontsdir}/*

%changelog
* Mon Aug 16 2021 Cor Blom <cornelis@solcon.nl>
- Revert update to Source Sans 3 and keep the pro versions
  (boo#1189267)
* Wed Aug  4 2021 Cor Blom <cornelis@solcon.nl>
- Add 31-adobe-sourcesanspro.conf so that old name still works
* Thu Jul 29 2021 tiwai@suse.de
- Fixed github URL
- Fixed Source URL again; we take the full source zip instead of
  split release zip
* Thu Jul 29 2021 Cor Blom <cornelis@solcon.nl>
- Update to version 3.046
  * Roman and Italic now are the same version
  * The "pro" part of the name has been dropped, internally a number
    is now used: Source Sans 3
  * Update URL
  * This is a major release with many changes. See the release page
    for the details:
    https://github.com/adobe-fonts/source-sans/releases
* Wed May 29 2019 Marguerite Su <i@marguerite.su>
- Update source url
* Mon May 27 2019 Cor Blom <cornelis@solcon.nl>
- Update to version 2.045 (Roman) and 1.095 (Italic):
  * Bugfixes (too many to name here)
- Run through spec cleaner
- Only package the (better) otf fonts (following the Source Code
  Pro package)
* Thu Oct  8 2015 fcrozat@suse.com
- Update to version 2.020 for Roman styles:
  * Changed vendor ID to ADBO.
  * Updated x-height measurements in all fonts.
  * Updated name table to remove full license text from binary font
    files.
  * Removed NULL (U+0000) and CR (U+000D) glyphs from TrueType
    fonts.
- Update to version 1.075 for Italic styles:
  * Updated right side bearing of quotedblbase and kerning of
  * baseline quotes.
  * Added narrow no-break space (U+202F).
  * Moved fi and fl ligatures to the end of glyph order.
- Update url to github.com.
* Wed Jul  9 2014 dmitry_r@opensuse.org
- Update to version 2.010 for Roman styles:
  * Geometric shapes were made larger.
  * Adds narrow no-break space U+202F.
  * Updates kerning of small caps and adds small cap punctuation.
  * Adds Cyrillic and Greek support.
  * Updates size and shape of diacritics.
  * Adjusts superscript height to coordinate baseline of letters and numbers.
- Update to version 1.065 for Italic styles:
  * Geometric shapes were made larger.
  * Updates size and shape of diacritics.
  * Adjusts superscript height to coordinate baseline of letters and numbers.
* Mon Jun 10 2013 fa0sck@gmail.com
- Install fonts without x-bit
* Mon May  6 2013 dmitry_r@opensuse.org
- Update to version 1.050
  * Coordinated the vertical alignment of the tops of the letters
    across all the styles at the various sizes.
* Tue Apr  9 2013 nwalter@suse.com
- updated to version 1.040
- improvement: Adds Zero_Width_Non_Breaking_Space character (ZWNBS, U+FEFF) to address GitHub issue #20
* Sat Oct 27 2012 toms@opensuse.org
- Update to version 1.038 (2012/09/12):
  * Updates the metrics of Majuscule letters in lighter weights.
  * Updates fonts to add small capitals and superior capital letters
  to upright styles.
  * Adds the following characters for transliteration: Blinebelow,
  blinebelow, Klinebelow klinebelow, Emacronacute, emacronacute,
  Omacronacute, omacronacute, primemod
  * Adds the following punctuation characters: bardbl, iterrobang,
  ceilingleft, ceilingright, floorleft floorright, bracketleftwhite,
  bracketrightwhite, brackhalftopleft, brackhalftopright, brackhalfbotleft,
  brackhalfbotright
  * Adds dotted zero and slashed zero.
* Fri Sep 28 2012 toms@opensuse.org
- Added Obsoletes and Provides
* Fri Sep 28 2012 toms@opensuse.org
- Renamed from SourceSansPro package, fixed .changes and .spec file
* Tue Sep 25 2012 toms@opensuse.org
- Spec: Use %%{_ttfontsdir} macro instead of %%{_datadir}
* Sun Sep 23 2012 toms@opensuse.org
- Updated to 1.0.36 release
  Updates fonts to fix bug in TTF versions in which the GDEF table
  was not included.
- 1.0.35 release:
  Updates the fitting for 'u' and its related glyphs. Updates the
  kerning in the upright fonts.
* Mon Aug 27 2012 toms@opensuse.org
- amend spec file to reflect new font packaging scheme
  (see openFATE#313536)
* Wed Aug 22 2012 toms@opensuse.org
- Included SourceSansProReadMe.html file into %%doc path
  (contains changelog)
* Tue Aug 21 2012 toms@opensuse.org
- Update to 1.0.34 release
- SPEC file changes:
  . Fix line endings for LICENSE.txt
  . Adapted to new structure in archive
  . Installed both, OTF and TTF files
* Sat Aug  4 2012 dimstar@opensuse.org
- Update to latest 1.033 release
  + No real change, except that we have proper version numbers.
* Fri Aug  3 2012 dimstar@opensuse.org
- Initial package, version from 2012-07-31.
